==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/pre/EarliestnessComputation.h <==
// public class soot.jimple.toolkits.scalar.pre.EarliestnessComputation

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5ef00c784a1f5327 soot_jimple_toolkits_scalar_pre_EarliestnessComputation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_EarliestnessComputation_H_
#define _JC_soot_jimple_toolkits_scalar_pre_EarliestnessComputation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SideEffectTester$object;
struct _jc_soot_jimple_toolkits_scalar_pre_DownSafetyAnalysis$object;
struct _jc_soot_jimple_toolkits_scalar_pre_UpSafetyAnalysis$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$refs	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vmethods	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtable	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$method$_init$e8663b8ed8ce16ca(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_soot_jimple_toolkits_scalar_pre_UpSafetyAnalysis$object *, struct _jc_soot_jimple_toolkits_scalar_pre_DownSafetyAnalysis$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$method$_init$bbad5824ed0ceb56(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_soot_jimple_toolkits_scalar_pre_UpSafetyAnalysis$object *, struct _jc_soot_jimple_toolkits_scalar_pre_DownSafetyAnalysis$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$method$getFlowBefore$af587dd021ceb8ac(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$method_info$getFlowBefore$af587dd021ceb8ac;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vmethods {
	struct _jc_java_lang_Object$object	*(*getFlowBefore$af587dd021ceb8ac)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vmethods	soot_jimple_toolkits_scalar_pre_EarliestnessComputation;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_refs {
	struct _jc_object	*unitToEarliest;
	struct _jc_object	*sideEffect;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$refs {
    _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_refs	soot_jimple_toolkits_scalar_pre_EarliestnessComputation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_nonrefs	soot_jimple_toolkits_scalar_pre_EarliestnessComputation;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object {
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_EarliestnessComputation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_EarliestnessComputation_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/pre/EarliestnessComputation.h <==
// public class soot.jimple.toolkits.scalar.pre.EarliestnessComputation

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5ef00c784a1f5327 soot_jimple_toolkits_scalar_pre_EarliestnessComputation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_EarliestnessComputation_H_
#define _JC_soot_jimple_toolkits_scalar_pre_EarliestnessComputation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SideEffectTester$object;
struct _jc_soot_jimple_toolkits_scalar_pre_DownSafetyAnalysis$object;
struct _jc_soot_jimple_toolkits_scalar_pre_UpSafetyAnalysis$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$refs	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vmethods	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtable	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$method$_init$e8663b8ed8ce16ca(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_soot_jimple_toolkits_scalar_pre_UpSafetyAnalysis$object *, struct _jc_soot_jimple_toolkits_scalar_pre_DownSafetyAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$method$_init$bbad5824ed0ceb56(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *, struct _jc_soot_jimple_toolkits_scalar_pre_UpSafetyAnalysis$object *, struct _jc_soot_jimple_toolkits_scalar_pre_DownSafetyAnalysis$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$method$getFlowBefore$af587dd021ceb8ac(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$method_info$getFlowBefore$af587dd021ceb8ac;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vmethods {
	struct _jc_java_lang_Object$object	*(*getFlowBefore$af587dd021ceb8ac)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vmethods	soot_jimple_toolkits_scalar_pre_EarliestnessComputation;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_refs {
	struct _jc_object	*unitToEarliest;
	struct _jc_object	*sideEffect;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$refs {
    _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_refs	soot_jimple_toolkits_scalar_pre_EarliestnessComputation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$sub_nonrefs	soot_jimple_toolkits_scalar_pre_EarliestnessComputation;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object {
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$vtype _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_EarliestnessComputation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_EarliestnessComputation_H_ */
